@@ -5,21 +5,21 @@ use super::*;
 /// The main class for parsing
 pub struct ArgParser {
     /// The name of the program
-    name: String,
+    pub name: String,
     /// The author of the program
-    author: String,
+    pub author: String,
     /// The version of the program
-    version: String,
+    pub version: String,
     /// Copyright string
-    copyright: String,
+    pub copyright: String,
     /// Simple description of the program
-    info: String,
+    pub info: String,
     /// Example usage of the program
-    usage: String,
+    pub usage: String,
     /// Vec holding all the arguments
     args: Vec<Arg>,
     /// Whether the program *has* to have arguments passed or not
-    require_args: bool,
+    pub require_args: bool,
     /// Any extra arguments that were passed, but not parsed
     pub extra: Vec<String>,
 }
